package dk.nsp.idsas.util;

import org.junit.Assert;
import org.junit.Test;

import java.nio.charset.StandardCharsets;
import java.util.UUID;

import static org.junit.Assert.fail;

public class UUIDv5Test {

    @Test
    public void generateUUIDv5_outputsAnUUIDv5() {
        // Arrange
        byte[] input = "test".getBytes(StandardCharsets.UTF_8);

        // Act
        UUID uuid = UUIDv5.generateUUIDFromBytes(input);

        // Assert
        int version = uuid.version();
        Assert.assertEquals(5, version);
    }

    @Test
    public void generateUUIDv5_outputIsConsistent() {
        // Arrange
        byte[] input = "test".getBytes(StandardCharsets.UTF_8);
        final String output = "26b9fa50-8032-5a58-a9d2-ddbc5df09deb";

        // Act
        UUID uuid = UUIDv5.generateUUIDFromBytes(input);

        // Assert
        String str = uuid.toString();
        Assert.assertEquals(output, str);
    }

    @Test
    public void generateUUIDv5_inputConsistency() {
        // Arrange
        byte[] input = "test".getBytes(StandardCharsets.UTF_8);

        // Act
        UUID uuid1 = UUIDv5.generateUUIDFromBytes(input);
        UUID uuid2 = UUIDv5.generateUUIDFromBytes(input);

        // Assert
        Assert.assertEquals(uuid1, uuid2);
    }

    @Test
    public void generateUUIDv5_differentInputs() {
        // Arrange
        byte[] input1 = "test1".getBytes(StandardCharsets.UTF_8);
        byte[] input2 = "test2".getBytes(StandardCharsets.UTF_8);

        // Act
        UUID uuid1 = UUIDv5.generateUUIDFromBytes(input1);
        UUID uuid2 = UUIDv5.generateUUIDFromBytes(input2);

        // Assert
        Assert.assertNotEquals(uuid1, uuid2);
    }

    @Test(expected = NullPointerException.class)
    public void generateUUIDv5_nullInput() {
        // Act
        UUIDv5.generateUUIDFromBytes(null);

        // Assert
        fail("NullPointerException expected");
    }

}