package dk.nsp.idsas.setup;

import dk.nsp.idsas.dao.BlurringDao;
import dk.nsp.idsas.service.LookupService;
import dk.nsp.idsas.util.AuditLogger;
import org.apache.commons.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.PropertySource;
import org.springframework.context.annotation.PropertySources;

@Configuration
@PropertySources({
        @PropertySource("classpath:/META-INF/maven/dk.nsp.idsas/idsas-lookup-web/pom.properties"),
        @PropertySource(value = "idsas-lookup.properties", encoding = "ISO-8859-1"),
        @PropertySource(value = "idsas-patient-id-salt.properties", encoding = "ISO-8859-1")
        // Bemærkning: I Java 8 er properties altid i ISO-8859-1, men fremadrettet skulle de gerne kunne være UTF-8.
})
public class WebSetup {

    @Value("${idsas.allowed.client.system.name:http://system.nspop.dk/sts}")
    private String allowedClientSystemName;

    @Value("${idsas.patient.id.salt:#{null}}")
    private String patientIdSaltEncoded;

    @Bean
    public LookupService lookupService(BlurringDao blurringDao, AuditLogger auditLogger) {
        // If patientIdSaltEncoded is null or empty
        if (patientIdSaltEncoded == null || patientIdSaltEncoded.isEmpty()) {
            throw new IllegalStateException("patientIdSalt cannot be empty or null");
        }

        byte[] patientIdSalt = Base64.decodeBase64(patientIdSaltEncoded.getBytes());
        return new LookupService(blurringDao, patientIdSalt, auditLogger, allowedClientSystemName);
    }
}
